# -*- Mode: Python -*-
# vi:si:et:sw=4:sts=4:ts=4

import os.path

from morituri.common import common


__thisdir = os.path.dirname(os.path.abspath(__file__))


def get():
    return {
        'isinstalled': False,
        'pluginsdir': os.path.abspath(os.path.join(
            __thisdir, '..', '..', 'plugins')),
        'version': '0.2.3',
        'revision': common.getRevision(),
    }
